% Espera que os motores se comecem a mover
%
% [stat,error,errorstr]=motionstart(H,scuid)
%
% H: Handler de comunicações
% scuid: Endereços a testar
%
% stat: Verdadeiro se os motores efectivamente se comecaram a mover
% error: Flag de erro
% errorstr: String de erro

function [stat,error,errorstr]=motionstart(H,scuid)

stat=0;
error=0;
errorstr='OK';

% Timeout para terminar o movimento
timeout=10;

% Espera que os motores se comecem a mover
finall=1;
while (finall==1)
    [finall,x,x,x,error,errorstr]=statmotionfin(H,scuid);
    if (error==1), return, end
end

% Os motores moveram-se?
stat=~finall;
